@@ -2,7 +2,7 @@ package Net::AMQP::RabbitMQ;
 use strict;
 use warnings;
 
-our $VERSION = '2.40008';
+our $VERSION = '2.40009';
 
 use XSLoader;
 XSLoader::load "Net::AMQP::RabbitMQ", $VERSION;
@@ -55,6 +55,13 @@ Error handling in this module is primarily achieve by C<Perl_croak> (die). You
 should be making good use of C<eval> around these methods to ensure that you
 appropriately catch the errors.
 
+=head1 INSTALLATION
+
+C<cpanm Net::AMQP::RabbitMQ> or C<cpan Net::AMQP::RabbitMQ>
+
+Note that the C<Net::AMQP::RabbitMQ> module includes the associated librabbitmq
+C library.  Thus there is no need to install this separately beforehand.
+
 =head1 METHODS
 
 All methods, unless specifically stated, return nothing on success
@@ -81,7 +88,7 @@ C<$options> is an optional hash respecting the following keys:
         vhost           => $vhost,       #default '/'
         channel_max     => $cmax,        #default 0
         frame_max       => $fmax,        #default 131072
-        heartbeat       => $hearbeat,    #default 0
+        heartbeat       => $heartbeat,   #default 0
         timeout         => $seconds,     #default undef (no timeout)
 
         ssl             => 1 | 0,        #default 0
@@ -499,6 +506,30 @@ Rollback a server-side (tx) transaction over $channel.
 
 C<$channel> is a channel that has been opened with C<channel_open>.
 
+=head2 get_rpc_timeout()
+
+Return the RPC timeout on the current connection.
+
+The value returned will be either C<undef>, if the RPC timeout is
+unlimited, or a hashref with C<tv_sec> for the number of seconds and
+C<tv_usec> for the number of microseconds.
+
+=head2 set_rpc_timeout({ tv_sec => SECONDS, tv_usec => MICROSECONDS })
+
+Set the RPC timeout for the current connection, using the seconds
+(C<tv_sec>) and microseconds (C<tv_usec>) provided. The arguments
+supplied can be either in the form of a hash or a hashref, so all of
+the following are valid:
+
+    $mq->set_rpc_timeout(tv_sec => 10, tv_usec => 500000)
+    $mq->set_rpc_timeout( { tv_sec => 10, tv_usec => 500000 } )
+    $mq->set_rpc_timeout(tv_sec => 10)
+    $mq->set_rpc_timeout(tv_usec => 500000)
+
+In order to remove the time limit for RPC calls, simply pass C<undef>.
+
+    $mq->set_rpc_timeout( undef )
+
 =head2 basic_qos($channel, $options)
 
 Set quality of service flags on the current $channel.
@@ -519,6 +550,9 @@ Send a heartbeat.  If you've connected with a heartbeat parameter,
 you must send a heartbeat periodically matching connection parameter or
 the server may snip the connection.
 
+Note that since C<recv> blocks for up to C<$timeout> milliseconds,
+it automatically handles sending heartbeats for you while active.
+
 =head2 has_ssl
 
 Returns true if the module was compiled with SSL support, false otherwise
@@ -685,7 +719,7 @@ Theo Schlossnagle E<lt>jesus@omniti.comE<gt>
 
 Mark Ellis E<lt>markellis@cpan.orgE<gt>
 
-Michael Stemle, Jr. E<lt>themanchicken@gmail.comE<gt>
+Mike "manchicken" Stemle, Jr. E<lt>mstemle@cpan.orgE<gt>
 
 Dave Rolsky E<lt>autarch@urth.orgE<gt>
 
@@ -751,11 +785,28 @@ sub publish {
     $self->_publish($channel, $routing_key, $body, $options, $props);
 }
 
+sub set_rpc_timeout {
+  my ($self, @opts) = @_;
+
+  my $args = undef;
+
+  # Be kind on whether or not we receive a hashref
+  # or an actual hash.
+  if ((scalar @opts % 2) == 0) {
+    $args = { @opts };
+  } elsif ( scalar @opts == 1 && defined $opts[0]) {
+    $args = $opts[0];
+  }
+
+  return $self->_set_rpc_timeout( $args );
+}
+
 sub DESTROY {
     my ($self) = @_;
-    $self->_destroy_connection_close
-        if !$have_fieldhash || $pids{$self} && $pids{$self} == $$;
-    $self->_destroy_cleanup;
+    if (!$have_fieldhash || $pids{$self} && $pids{$self} == $$) {
+      $self->_destroy_connection_close;
+      $self->_destroy_cleanup;
+    }
 }
 
 1;
