@@ -1,4 +1,3 @@
-/* vim:set ft=c ts=2 sw=2 sts=2 et cindent: */
 /*
  * ***** BEGIN LICENSE BLOCK *****
  * Version: MIT
@@ -49,22 +48,16 @@
 #define INITIAL_ARRAY_SIZE 16
 #define INITIAL_TABLE_SIZE 16
 
-static int amqp_decode_field_value(amqp_bytes_t encoded,
-                                   amqp_pool_t *pool,
-                                   amqp_field_value_t *entry,
-                                   size_t *offset);
+static int amqp_decode_field_value(amqp_bytes_t encoded, amqp_pool_t *pool,
+                                   amqp_field_value_t *entry, size_t *offset);
 
 static int amqp_encode_field_value(amqp_bytes_t encoded,
-                                   amqp_field_value_t *entry,
-                                   size_t *offset);
+                                   amqp_field_value_t *entry, size_t *offset);
 
 /*---------------------------------------------------------------------------*/
 
-static int amqp_decode_array(amqp_bytes_t encoded,
-                             amqp_pool_t *pool,
-                             amqp_array_t *output,
-                             size_t *offset)
-{
+static int amqp_decode_array(amqp_bytes_t encoded, amqp_pool_t *pool,
+                             amqp_array_t *output, size_t *offset) {
   uint32_t arraysize;
   int num_entries = 0;
   int allocated_entries = INITIAL_ARRAY_SIZE;
@@ -76,6 +69,10 @@ static int amqp_decode_array(amqp_bytes_t encoded,
     return AMQP_STATUS_BAD_AMQP_DATA;
   }
 
+  if (arraysize + *offset > encoded.len) {
+    return AMQP_STATUS_BAD_AMQP_DATA;
+  }
+
   entries = malloc(allocated_entries * sizeof(amqp_field_value_t));
   if (entries == NULL) {
     return AMQP_STATUS_NO_MEMORY;
@@ -86,7 +83,8 @@ static int amqp_decode_array(amqp_bytes_t encoded,
     if (num_entries >= allocated_entries) {
       void *newentries;
       allocated_entries = allocated_entries * 2;
-      newentries = realloc(entries, allocated_entries * sizeof(amqp_field_value_t));
+      newentries =
+          realloc(entries, allocated_entries * sizeof(amqp_field_value_t));
       res = AMQP_STATUS_NO_MEMORY;
       if (newentries == NULL) {
         goto out;
@@ -95,8 +93,7 @@ static int amqp_decode_array(amqp_bytes_t encoded,
       entries = newentries;
     }
 
-    res = amqp_decode_field_value(encoded, pool, &entries[num_entries],
-                                  offset);
+    res = amqp_decode_field_value(encoded, pool, &entries[num_entries], offset);
     if (res < 0) {
       goto out;
     }
@@ -105,26 +102,28 @@ static int amqp_decode_array(amqp_bytes_t encoded,
   }
 
   output->num_entries = num_entries;
-  output->entries = amqp_pool_alloc(pool, num_entries * sizeof(amqp_field_value_t));
-  res = AMQP_STATUS_NO_MEMORY;
+  output->entries =
+      amqp_pool_alloc(pool, num_entries * sizeof(amqp_field_value_t));
   /* NULL is legitimate if we requested a zero-length block. */
-  if (output->entries == NULL && num_entries > 0) {
+  if (output->entries == NULL) {
+    if (num_entries == 0) {
+      res = AMQP_STATUS_OK;
+    } else {
+      res = AMQP_STATUS_NO_MEMORY;
+    }
     goto out;
   }
 
   memcpy(output->entries, entries, num_entries * sizeof(amqp_field_value_t));
-  res = 0;
+  res = AMQP_STATUS_OK;
 
 out:
   free(entries);
   return res;
 }
 
-int amqp_decode_table(amqp_bytes_t encoded,
-                      amqp_pool_t *pool,
-                      amqp_table_t *output,
-                      size_t *offset)
-{
+int amqp_decode_table(amqp_bytes_t encoded, amqp_pool_t *pool,
+                      amqp_table_t *output, size_t *offset) {
   uint32_t tablesize;
   int num_entries = 0;
   amqp_table_entry_t *entries;
@@ -136,6 +135,10 @@ int amqp_decode_table(amqp_bytes_t encoded,
     return AMQP_STATUS_BAD_AMQP_DATA;
   }
 
+  if (tablesize + *offset > encoded.len) {
+    return AMQP_STATUS_BAD_AMQP_DATA;
+  }
+
   entries = malloc(allocated_entries * sizeof(amqp_table_entry_t));
   if (entries == NULL) {
     return AMQP_STATUS_NO_MEMORY;
@@ -153,7 +156,8 @@ int amqp_decode_table(amqp_bytes_t encoded,
     if (num_entries >= allocated_entries) {
       void *newentries;
       allocated_entries = allocated_entries * 2;
-      newentries = realloc(entries, allocated_entries * sizeof(amqp_table_entry_t));
+      newentries =
+          realloc(entries, allocated_entries * sizeof(amqp_table_entry_t));
       res = AMQP_STATUS_NO_MEMORY;
       if (newentries == NULL) {
         goto out;
@@ -163,7 +167,8 @@ int amqp_decode_table(amqp_bytes_t encoded,
     }
 
     res = AMQP_STATUS_BAD_AMQP_DATA;
-    if (!amqp_decode_bytes(encoded, offset, &entries[num_entries].key, keylen)) {
+    if (!amqp_decode_bytes(encoded, offset, &entries[num_entries].key,
+                           keylen)) {
       goto out;
     }
 
@@ -177,10 +182,15 @@ int amqp_decode_table(amqp_bytes_t encoded,
   }
 
   output->num_entries = num_entries;
-  output->entries = amqp_pool_alloc(pool, num_entries * sizeof(amqp_table_entry_t));
-  res = AMQP_STATUS_NO_MEMORY;
+  output->entries =
+      amqp_pool_alloc(pool, num_entries * sizeof(amqp_table_entry_t));
   /* NULL is legitimate if we requested a zero-length block. */
-  if (output->entries == NULL && num_entries > 0) {
+  if (output->entries == NULL) {
+    if (num_entries == 0) {
+      res = AMQP_STATUS_OK;
+    } else {
+      res = AMQP_STATUS_NO_MEMORY;
+    }
     goto out;
   }
 
@@ -192,88 +202,93 @@ out:
   return res;
 }
 
-static int amqp_decode_field_value(amqp_bytes_t encoded,
-                                   amqp_pool_t *pool,
-                                   amqp_field_value_t *entry,
-                                   size_t *offset)
-{
+static int amqp_decode_field_value(amqp_bytes_t encoded, amqp_pool_t *pool,
+                                   amqp_field_value_t *entry, size_t *offset) {
   int res = AMQP_STATUS_BAD_AMQP_DATA;
 
   if (!amqp_decode_8(encoded, offset, &entry->kind)) {
     goto out;
   }
 
-#define TRIVIAL_FIELD_DECODER(bits) if (!amqp_decode_##bits(encoded, offset, &entry->value.u##bits)) goto out; break
-#define SIMPLE_FIELD_DECODER(bits, dest, how) { uint##bits##_t val; if (!amqp_decode_##bits(encoded, offset, &val)) goto out; entry->value.dest = how; } break
+#define TRIVIAL_FIELD_DECODER(bits)                                          \
+  if (!amqp_decode_##bits(encoded, offset, &entry->value.u##bits)) goto out; \
+  break
+#define SIMPLE_FIELD_DECODER(bits, dest, how)                 \
+  {                                                           \
+    uint##bits##_t val;                                       \
+    if (!amqp_decode_##bits(encoded, offset, &val)) goto out; \
+    entry->value.dest = how;                                  \
+  }                                                           \
+  break
 
   switch (entry->kind) {
-  case AMQP_FIELD_KIND_BOOLEAN:
-    SIMPLE_FIELD_DECODER(8, boolean, val ? 1 : 0);
+    case AMQP_FIELD_KIND_BOOLEAN:
+      SIMPLE_FIELD_DECODER(8, boolean, val ? 1 : 0);
 
-  case AMQP_FIELD_KIND_I8:
-    SIMPLE_FIELD_DECODER(8, i8, (int8_t)val);
-  case AMQP_FIELD_KIND_U8:
-    TRIVIAL_FIELD_DECODER(8);
+    case AMQP_FIELD_KIND_I8:
+      SIMPLE_FIELD_DECODER(8, i8, (int8_t)val);
+    case AMQP_FIELD_KIND_U8:
+      TRIVIAL_FIELD_DECODER(8);
 
-  case AMQP_FIELD_KIND_I16:
-    SIMPLE_FIELD_DECODER(16, i16, (int16_t)val);
-  case AMQP_FIELD_KIND_U16:
-    TRIVIAL_FIELD_DECODER(16);
+    case AMQP_FIELD_KIND_I16:
+      SIMPLE_FIELD_DECODER(16, i16, (int16_t)val);
+    case AMQP_FIELD_KIND_U16:
+      TRIVIAL_FIELD_DECODER(16);
 
-  case AMQP_FIELD_KIND_I32:
-    SIMPLE_FIELD_DECODER(32, i32, (int32_t)val);
-  case AMQP_FIELD_KIND_U32:
-    TRIVIAL_FIELD_DECODER(32);
+    case AMQP_FIELD_KIND_I32:
+      SIMPLE_FIELD_DECODER(32, i32, (int32_t)val);
+    case AMQP_FIELD_KIND_U32:
+      TRIVIAL_FIELD_DECODER(32);
 
-  case AMQP_FIELD_KIND_I64:
-    SIMPLE_FIELD_DECODER(64, i64, (int64_t)val);
-  case AMQP_FIELD_KIND_U64:
-    TRIVIAL_FIELD_DECODER(64);
+    case AMQP_FIELD_KIND_I64:
+      SIMPLE_FIELD_DECODER(64, i64, (int64_t)val);
+    case AMQP_FIELD_KIND_U64:
+      TRIVIAL_FIELD_DECODER(64);
 
-  case AMQP_FIELD_KIND_F32:
-    TRIVIAL_FIELD_DECODER(32);
-    /* and by punning, f32 magically gets the right value...! */
+    case AMQP_FIELD_KIND_F32:
+      TRIVIAL_FIELD_DECODER(32);
+      /* and by punning, f32 magically gets the right value...! */
 
-  case AMQP_FIELD_KIND_F64:
-    TRIVIAL_FIELD_DECODER(64);
-    /* and by punning, f64 magically gets the right value...! */
+    case AMQP_FIELD_KIND_F64:
+      TRIVIAL_FIELD_DECODER(64);
+      /* and by punning, f64 magically gets the right value...! */
 
-  case AMQP_FIELD_KIND_DECIMAL:
-    if (!amqp_decode_8(encoded, offset, &entry->value.decimal.decimals)
-        || !amqp_decode_32(encoded, offset, &entry->value.decimal.value)) {
-      goto out;
-    }
-    break;
+    case AMQP_FIELD_KIND_DECIMAL:
+      if (!amqp_decode_8(encoded, offset, &entry->value.decimal.decimals) ||
+          !amqp_decode_32(encoded, offset, &entry->value.decimal.value)) {
+        goto out;
+      }
+      break;
 
-  case AMQP_FIELD_KIND_UTF8:
+    case AMQP_FIELD_KIND_UTF8:
     /* AMQP_FIELD_KIND_UTF8 and AMQP_FIELD_KIND_BYTES have the
        same implementation, but different interpretations. */
     /* fall through */
-  case AMQP_FIELD_KIND_BYTES: {
-    uint32_t len;
-    if (!amqp_decode_32(encoded, offset, &len)
-        || !amqp_decode_bytes(encoded, offset, &entry->value.bytes, len)) {
-      goto out;
+    case AMQP_FIELD_KIND_BYTES: {
+      uint32_t len;
+      if (!amqp_decode_32(encoded, offset, &len) ||
+          !amqp_decode_bytes(encoded, offset, &entry->value.bytes, len)) {
+        goto out;
+      }
+      break;
     }
-    break;
-  }
 
-  case AMQP_FIELD_KIND_ARRAY:
-    res = amqp_decode_array(encoded, pool, &(entry->value.array), offset);
-    goto out;
+    case AMQP_FIELD_KIND_ARRAY:
+      res = amqp_decode_array(encoded, pool, &(entry->value.array), offset);
+      goto out;
 
-  case AMQP_FIELD_KIND_TIMESTAMP:
-    TRIVIAL_FIELD_DECODER(64);
+    case AMQP_FIELD_KIND_TIMESTAMP:
+      TRIVIAL_FIELD_DECODER(64);
 
-  case AMQP_FIELD_KIND_TABLE:
-    res = amqp_decode_table(encoded, pool, &(entry->value.table), offset);
-    goto out;
+    case AMQP_FIELD_KIND_TABLE:
+      res = amqp_decode_table(encoded, pool, &(entry->value.table), offset);
+      goto out;
 
-  case AMQP_FIELD_KIND_VOID:
-    break;
+    case AMQP_FIELD_KIND_VOID:
+      break;
 
-  default:
-    goto out;
+    default:
+      goto out;
   }
 
   res = AMQP_STATUS_OK;
@@ -284,10 +299,8 @@ out:
 
 /*---------------------------------------------------------------------------*/
 
-static int amqp_encode_array(amqp_bytes_t encoded,
-                             amqp_array_t *input,
-                             size_t *offset)
-{
+static int amqp_encode_array(amqp_bytes_t encoded, amqp_array_t *input,
+                             size_t *offset) {
   size_t start = *offset;
   int i, res;
 
@@ -311,10 +324,8 @@ out:
   return res;
 }
 
-int amqp_encode_table(amqp_bytes_t encoded,
-                      amqp_table_t *input,
-                      size_t *offset)
-{
+int amqp_encode_table(amqp_bytes_t encoded, amqp_table_t *input,
+                      size_t *offset) {
   size_t start = *offset;
   int i, res;
 
@@ -349,90 +360,89 @@ out:
 }
 
 static int amqp_encode_field_value(amqp_bytes_t encoded,
-                                   amqp_field_value_t *entry,
-                                   size_t *offset)
-{
+                                   amqp_field_value_t *entry, size_t *offset) {
   int res = AMQP_STATUS_BAD_AMQP_DATA;
 
   if (!amqp_encode_8(encoded, offset, entry->kind)) {
     goto out;
   }
 
-#define FIELD_ENCODER(bits, val) if (!amqp_encode_##bits(encoded, offset, val)) { \
-                                    res = AMQP_STATUS_TABLE_TOO_BIG;              \
-                                    goto out;                                     \
-                                  }                                               \
-                                  break
+#define FIELD_ENCODER(bits, val)                   \
+  if (!amqp_encode_##bits(encoded, offset, val)) { \
+    res = AMQP_STATUS_TABLE_TOO_BIG;               \
+    goto out;                                      \
+  }                                                \
+  break
 
   switch (entry->kind) {
-  case AMQP_FIELD_KIND_BOOLEAN:
-    FIELD_ENCODER(8, entry->value.boolean ? 1 : 0);
+    case AMQP_FIELD_KIND_BOOLEAN:
+      FIELD_ENCODER(8, entry->value.boolean ? 1 : 0);
 
-  case AMQP_FIELD_KIND_I8:
-    FIELD_ENCODER(8, entry->value.i8);
-  case AMQP_FIELD_KIND_U8:
-    FIELD_ENCODER(8, entry->value.u8);
+    case AMQP_FIELD_KIND_I8:
+      FIELD_ENCODER(8, entry->value.i8);
+    case AMQP_FIELD_KIND_U8:
+      FIELD_ENCODER(8, entry->value.u8);
 
-  case AMQP_FIELD_KIND_I16:
-    FIELD_ENCODER(16, entry->value.i16);
-  case AMQP_FIELD_KIND_U16:
-    FIELD_ENCODER(16, entry->value.u16);
+    case AMQP_FIELD_KIND_I16:
+      FIELD_ENCODER(16, entry->value.i16);
+    case AMQP_FIELD_KIND_U16:
+      FIELD_ENCODER(16, entry->value.u16);
 
-  case AMQP_FIELD_KIND_I32:
-    FIELD_ENCODER(32, entry->value.i32);
-  case AMQP_FIELD_KIND_U32:
-    FIELD_ENCODER(32, entry->value.u32);
+    case AMQP_FIELD_KIND_I32:
+      FIELD_ENCODER(32, entry->value.i32);
+    case AMQP_FIELD_KIND_U32:
+      FIELD_ENCODER(32, entry->value.u32);
 
-  case AMQP_FIELD_KIND_I64:
-    FIELD_ENCODER(64, entry->value.i64);
-  case AMQP_FIELD_KIND_U64:
-    FIELD_ENCODER(64, entry->value.u64);
+    case AMQP_FIELD_KIND_I64:
+      FIELD_ENCODER(64, entry->value.i64);
+    case AMQP_FIELD_KIND_U64:
+      FIELD_ENCODER(64, entry->value.u64);
 
-  case AMQP_FIELD_KIND_F32:
-    /* by punning, u32 magically gets the right value...! */
-    FIELD_ENCODER(32, entry->value.u32);
+    case AMQP_FIELD_KIND_F32:
+      /* by punning, u32 magically gets the right value...! */
+      FIELD_ENCODER(32, entry->value.u32);
 
-  case AMQP_FIELD_KIND_F64:
-    /* by punning, u64 magically gets the right value...! */
-    FIELD_ENCODER(64, entry->value.u64);
+    case AMQP_FIELD_KIND_F64:
+      /* by punning, u64 magically gets the right value...! */
+      FIELD_ENCODER(64, entry->value.u64);
 
-  case AMQP_FIELD_KIND_DECIMAL:
-    if (!amqp_encode_8(encoded, offset, entry->value.decimal.decimals)
-        || !amqp_encode_32(encoded, offset, entry->value.decimal.value)) {
-      res = AMQP_STATUS_TABLE_TOO_BIG;
-      goto out;
-    }
-    break;
+    case AMQP_FIELD_KIND_DECIMAL:
+      if (!amqp_encode_8(encoded, offset, entry->value.decimal.decimals) ||
+          !amqp_encode_32(encoded, offset, entry->value.decimal.value)) {
+        res = AMQP_STATUS_TABLE_TOO_BIG;
+        goto out;
+      }
+      break;
 
-  case AMQP_FIELD_KIND_UTF8:
+    case AMQP_FIELD_KIND_UTF8:
     /* AMQP_FIELD_KIND_UTF8 and AMQP_FIELD_KIND_BYTES have the
        same implementation, but different interpretations. */
     /* fall through */
-  case AMQP_FIELD_KIND_BYTES:
-    if (!amqp_encode_32(encoded, offset, (uint32_t)entry->value.bytes.len)
-        || !amqp_encode_bytes(encoded, offset, entry->value.bytes)) {
-      res = AMQP_STATUS_TABLE_TOO_BIG;
+    case AMQP_FIELD_KIND_BYTES:
+      if (!amqp_encode_32(encoded, offset, (uint32_t)entry->value.bytes.len) ||
+          !amqp_encode_bytes(encoded, offset, entry->value.bytes)) {
+        res = AMQP_STATUS_TABLE_TOO_BIG;
+        goto out;
+      }
+      break;
+
+    case AMQP_FIELD_KIND_ARRAY:
+      res = amqp_encode_array(encoded, &entry->value.array, offset);
       goto out;
-    }
-    break;
 
-  case AMQP_FIELD_KIND_ARRAY:
-    res = amqp_encode_array(encoded, &entry->value.array, offset);
-    goto out;
+    case AMQP_FIELD_KIND_TIMESTAMP:
+      FIELD_ENCODER(64, entry->value.u64);
 
-  case AMQP_FIELD_KIND_TIMESTAMP:
-    FIELD_ENCODER(64, entry->value.u64);
+    case AMQP_FIELD_KIND_TABLE:
+      res = amqp_encode_table(encoded, &entry->value.table, offset);
+      goto out;
 
-  case AMQP_FIELD_KIND_TABLE:
-    res = amqp_encode_table(encoded, &entry->value.table, offset);
-    goto out;
+    case AMQP_FIELD_KIND_VOID:
+      break;
 
-  case AMQP_FIELD_KIND_VOID:
-    break;
-
-  default:
-    res = AMQP_STATUS_INVALID_PARAMETER;
-    goto out;
+    default:
+      res = AMQP_STATUS_INVALID_PARAMETER;
+      goto out;
   }
 
   res = AMQP_STATUS_OK;
@@ -443,10 +453,9 @@ out:
 
 /*---------------------------------------------------------------------------*/
 
-int amqp_table_entry_cmp(void const *entry1, void const *entry2)
-{
-  amqp_table_entry_t const *p1 = (amqp_table_entry_t const *) entry1;
-  amqp_table_entry_t const *p2 = (amqp_table_entry_t const *) entry2;
+int amqp_table_entry_cmp(void const *entry1, void const *entry2) {
+  amqp_table_entry_t const *p1 = (amqp_table_entry_t const *)entry1;
+  amqp_table_entry_t const *p2 = (amqp_table_entry_t const *)entry2;
 
   int d;
   size_t minlen;
@@ -464,9 +473,9 @@ int amqp_table_entry_cmp(void const *entry1, void const *entry2)
   return (int)p1->key.len - (int)p2->key.len;
 }
 
-static int
-amqp_field_value_clone(const amqp_field_value_t *original, amqp_field_value_t *clone, amqp_pool_t *pool)
-{
+static int amqp_field_value_clone(const amqp_field_value_t *original,
+                                  amqp_field_value_t *clone,
+                                  amqp_pool_t *pool) {
   int i;
   int res;
   clone->kind = original->kind;
@@ -526,11 +535,13 @@ amqp_field_value_clone(const amqp_field_value_t *original, amqp_field_value_t *c
       if (0 == original->value.bytes.len) {
         clone->value.bytes = amqp_empty_bytes;
       } else {
-        amqp_pool_alloc_bytes(pool, original->value.bytes.len, &clone->value.bytes);
+        amqp_pool_alloc_bytes(pool, original->value.bytes.len,
+                              &clone->value.bytes);
         if (NULL == clone->value.bytes.bytes) {
           return AMQP_STATUS_NO_MEMORY;
         }
-        memcpy(clone->value.bytes.bytes, original->value.bytes.bytes, clone->value.bytes.len);
+        memcpy(clone->value.bytes.bytes, original->value.bytes.bytes,
+               clone->value.bytes.len);
       }
       break;
 
@@ -539,13 +550,15 @@ amqp_field_value_clone(const amqp_field_value_t *original, amqp_field_value_t *c
         clone->value.array = amqp_empty_array;
       } else {
         clone->value.array.num_entries = original->value.array.num_entries;
-        clone->value.array.entries = amqp_pool_alloc(pool, clone->value.array.num_entries * sizeof(amqp_field_value_t));
+        clone->value.array.entries = amqp_pool_alloc(
+            pool, clone->value.array.num_entries * sizeof(amqp_field_value_t));
         if (NULL == clone->value.array.entries) {
           return AMQP_STATUS_NO_MEMORY;
         }
 
         for (i = 0; i < clone->value.array.num_entries; ++i) {
-          res = amqp_field_value_clone(&original->value.array.entries[i], &clone->value.array.entries[i], pool);
+          res = amqp_field_value_clone(&original->value.array.entries[i],
+                                       &clone->value.array.entries[i], pool);
           if (AMQP_STATUS_OK != res) {
             return res;
           }
@@ -554,7 +567,8 @@ amqp_field_value_clone(const amqp_field_value_t *original, amqp_field_value_t *c
       break;
 
     case AMQP_FIELD_KIND_TABLE:
-      return amqp_table_clone(&original->value.table, &clone->value.table, pool);
+      return amqp_table_clone(&original->value.table, &clone->value.table,
+                              pool);
 
     case AMQP_FIELD_KIND_VOID:
       break;
@@ -566,10 +580,9 @@ amqp_field_value_clone(const amqp_field_value_t *original, amqp_field_value_t *c
   return AMQP_STATUS_OK;
 }
 
-
-static int
-amqp_table_entry_clone(const amqp_table_entry_t *original, amqp_table_entry_t *clone, amqp_pool_t *pool)
-{
+static int amqp_table_entry_clone(const amqp_table_entry_t *original,
+                                  amqp_table_entry_t *clone,
+                                  amqp_pool_t *pool) {
   if (0 == original->key.len) {
     return AMQP_STATUS_INVALID_PARAMETER;
   }
@@ -584,9 +597,8 @@ amqp_table_entry_clone(const amqp_table_entry_t *original, amqp_table_entry_t *c
   return amqp_field_value_clone(&original->value, &clone->value, pool);
 }
 
-int
-amqp_table_clone(const amqp_table_t *original, amqp_table_t *clone, amqp_pool_t *pool)
-{
+int amqp_table_clone(const amqp_table_t *original, amqp_table_t *clone,
+                     amqp_pool_t *pool) {
   int i;
   int res;
   clone->num_entries = original->num_entries;
@@ -595,14 +607,16 @@ amqp_table_clone(const amqp_table_t *original, amqp_table_t *clone, amqp_pool_t
     return AMQP_STATUS_OK;
   }
 
-  clone->entries = amqp_pool_alloc(pool, clone->num_entries * sizeof(amqp_table_entry_t));
+  clone->entries =
+      amqp_pool_alloc(pool, clone->num_entries * sizeof(amqp_table_entry_t));
 
   if (NULL == clone->entries) {
     return AMQP_STATUS_NO_MEMORY;
   }
 
   for (i = 0; i < clone->num_entries; ++i) {
-    res = amqp_table_entry_clone(&original->entries[i], &clone->entries[i], pool);
+    res =
+        amqp_table_entry_clone(&original->entries[i], &clone->entries[i], pool);
     if (AMQP_STATUS_OK != res) {
       goto error_out1;
     }
