@@ -142,6 +142,23 @@ sub connect {
     } );
 }
 
+sub get_connection_options {
+    my ( $self ) = @_;
+
+    return {
+        user            => $self->{username},
+        password        => $self->{password},
+        port            => $self->{port},
+        ssl             => $self->{ssl},
+        ssl_verify_host => $self->{ssl_verify_host},
+        ssl_verify_peer => $self->{ssl_verify_peer},
+        ssl_cacert      => $self->{ssl_cacert},
+        ssl_init        => $self->{ssl_init},
+        vhost           => $self->{vhost},
+    };
+
+}
+
 sub heartbeat {
     my $self = shift;
 
